(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = global || self, factory(global.genUnit = {}));
}(this, (function (exports) { 'use strict';

  function sortByPreLength(a, b) {
    return b.pre.length - a.pre.length;
  }

  var defaultTable = "f:-15;p:-12;n:-9;u:-6;m:-3;k:3;K:3;M:6;meg:6;G:9;T:12".split(";").map(function (s) {
    var _s$split = s.split(":"),
        pre = _s$split[0],
        pow = _s$split[1];

    return {
      pre: pre,
      power: +pow
    };
  }).sort(sortByPreLength);
  function createParser(options) {
    var _ref = options || {},
        unitOp = _ref.unit,
        tableOp = _ref.table;

    var table = tableOp || defaultTable;
    return function (input) {
      var asString = "" + input;
      var asNum = +asString;

      if (!isNaN(asNum)) {
        return asNum;
      }

      var result = /^\s*(\-?\d+\.?\d*)\s*(\w*)\s*$/.exec(asString);

      if (!result) {
        return null;
      }

      var valueStr = result[1],
          unit = result[2];
      var val = +valueStr;

      if (unitOp && unit === unitOp) {
        return val;
      }

      for (var _iterator = table, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
        var _ref2;

        if (_isArray) {
          if (_i >= _iterator.length) break;
          _ref2 = _iterator[_i++];
        } else {
          _i = _iterator.next();
          if (_i.done) break;
          _ref2 = _i.value;
        }

        var _ref3 = _ref2,
            pre = _ref3.pre,
            power = _ref3.power;

        if (unit === pre || unitOp && unit === pre + unitOp) {
          return val * Math.pow(10, power);
        }
      }

      return null;
    };
  }

  function sortByPower(a, b) {
    return b.power - a.power;
  }

  var defaultTable$1 = "T:12;G:9;M:6;K:3;:0;m:-3;\xB5:-6;n:-9;p:-12;f:-15".split(";").map(function (s) {
    var _s$split = s.split(":"),
        pre = _s$split[0],
        pow = _s$split[1];

    return {
      power: +pow,
      pre: pre
    };
  }).sort(sortByPower);

  function findUnit(pow, table) {
    return table.find(function (_ref) {
      var power = _ref.power;
      return power <= pow;
    }) || table[table.length - 1];
  }

  function createFormatter(options) {
    var _ref2 = options || {},
        unitOp = _ref2.unit,
        tableOp = _ref2.table,
        decOp = _ref2.dec,
        fixed = _ref2.fixed;

    if (decOp != null && typeof decOp !== "number") {
      throw new TypeError("invalid \"dec\" option.");
    }

    var unit = unitOp || "";
    var table = tableOp || defaultTable$1;
    var dec = decOp != null ? decOp : 4;
    return function (value) {
      var unitObj = findUnit(value ? Math.floor(Math.log10(Math.abs(value))) : 0, table);
      var val = value / Math.pow(10, unitObj.power);
      var mul = Math.pow(10, dec);
      var rounded = fixed ? val.toFixed(dec) : Math.round(val * mul) / mul;
      return rounded + " " + (unitObj.pre + unit);
    };
  }

  exports.createFormatter = createFormatter;
  exports.createParser = createParser;

})));
//# sourceMappingURL=gen-unit.umd.js.map
